import { virtual } from 'haunted';
import { html } from 'lit-html';
import { Icon } from '../icon';
import { ifDefined } from 'lit-html/directives/if-defined.js';
import { isEventClick, isKeyEnterOrKeySpace } from 'a11y-key-conjurer';
import { classMap } from 'lit-html/directives/class-map.js';

export const Controls = virtual(({ props, handleAudio, literals = {} }) => {
  const { isPlaying = false, playlist, indexSelected } = props;
  const controlsDisabled = !Number.isInteger(indexSelected);
  const controlItems = [
    {
      label: literals.previousTrack,
      icon: 'skip-previous',
      isDisabled: controlsDisabled || indexSelected === 0,
      action: handleAudio.previous
    },
    isPlaying && !controlsDisabled
      ? {
          label: literals.pause,
          icon: 'pause',
          action: handleAudio.pause,
          isDisabled: false
        }
      : {
          label: literals.play,
          icon: 'play-arrow',
          action: handleAudio.play,
          isDisabled: controlsDisabled
        },
    {
      label: literals.stop,
      icon: 'stop',
      isDisabled: controlsDisabled,
      action: handleAudio.stop
    },
    {
      label: literals.nextTrack,
      icon: 'skip-next',
      isDisabled: controlsDisabled || playlist.length - 1 === indexSelected,
      action: handleAudio.next
    }
  ];

  function handleControl(action) {
    return ev => {
      if (isEventClick(ev) || isKeyEnterOrKeySpace(ev)) {
        ev.preventDefault();
        action();
      }
    };
  }

  return html`
    <div class="myth-controls">
      <ul class="myth-controls__items">
        ${controlItems.map(item => {
          const buttonClasses = classMap({
            'myth-controls__button': true,
            'is-disabled': item.isDisabled
          });
          return html`
            <li class="myth-controls__item">
              <button
                class="${buttonClasses}"
                aria-label="${item.label}"
                disabled="${ifDefined(
                  item.isDisabled ? 'disabled' : undefined
                )}"
                @click="${handleControl(item.action)}"
                @keydown="${handleControl(item.action)}"
              >
                ${Icon({
                  icon: item.icon,
                  extraClasses: 'myth-controls__icon'
                })}
              </button>
            </li>
          `;
        })}
      </ul>
    </div>
  `;
});
