import { html } from 'lit-html';
import { classMap } from 'lit-html/directives/class-map.js';
import { ifDefined } from 'lit-html/directives/if-defined.js';
import { createComponent } from '../../_lib/create-component';
import { Icon } from '../icon';

function CoverFallbackComponent(element) {
  const { props, icon = 'audiotrack' } = element;
  const { isInFileItem } = props;
  const mainClasses = classMap({
    'cover-fallback': true,
    'cover-fallback--in-file-item': isInFileItem
  });
  return html`
    <div class="${mainClasses}">
      <div class="cover-fallback__icon">
        ${Icon({ icon, extraClasses: 'cover-fallback__icon-inner' })}
      </div>
    </div>
  `;
}

export function CoverFallback(props) {
  createComponent({
    name: 'mythical-cover-fallback',
    observedAttributes: ['icon'],
    fnComponent: CoverFallbackComponent,
    useShadowDOM: false
  });

  const { extraClasses, icon = null } = props;

  return html`
    <mythical-cover-fallback
      class="${ifDefined(extraClasses || undefined)}"
      icon="${ifDefined(icon || undefined)}"
      .props="${props}"
    ></mythical-cover-fallback>
  `;
}
