import { virtual } from 'haunted';
import { html, nothing } from 'lit-html';
import { isKeyEnterOrKeySpace, isEventClick } from 'a11y-key-conjurer';
import { classMap } from 'lit-html/directives/class-map.js';
import { TrackText } from '../track-text';
import { Icon } from '../icon';
import { FileExtension } from '../file-extension';
import { ItemDuration } from './modules/item-duration';
import { ShowCover } from './modules/show-cover';

export const Playlist = virtual(
  ({ playlist, list = {}, indexSelected, isPlaying, handleAudio, listId }) => {
    const {
      showCovers = true,
      showTrackNumber = true,
      showIconIsPlaying = true,
      showFileExtension = true
    } = list;
    function handleButton(index) {
      return ev => {
        if (isEventClick(ev) || isKeyEnterOrKeySpace(ev)) {
          ev.preventDefault();
          handleAudio.setTrack({ index, fromControls: false });
        }
      };
    }
    return html`
      <div class="myth-playlist" id="${listId}">
        <ul class="myth-playlist__items">
          ${playlist.map((item, index) => {
            const isPlayingItem = indexSelected === index;
            const itemClasses = classMap({
              'myth-playlist__item': true,
              'is-playing': isPlayingItem
            });
            return html`
              <li class="${itemClasses}" data-playlist-item="${index}">
                <div
                  class="myth-playlist__item-button"
                  tabindex="0"
                  role="button"
                  @click="${handleButton(index)}"
                  @keydown="${handleButton(index)}"
                >
                  ${showCovers ? ShowCover({ cover: item.cover }) : nothing}
                  ${showIconIsPlaying && isPlayingItem
                    ? html`
                        <div
                          class="myth-playlist__item-block myth-playlist__item-playing-icon"
                        >
                          ${Icon({
                            icon: isPlaying ? 'play-arrow' : 'pause',
                            extraClasses:
                              'myth-playlist__item-playing-icon-inner'
                          })}
                        </div>
                      `
                    : nothing}
                  ${showTrackNumber
                    ? html`
                        <div
                          class="myth-playlist__item-block myth-item-text size-small"
                        >
                          ${item.trackNumber || index + 1}
                        </div>
                      `
                    : nothing}
                  <div class="myth-playlist__item-block">
                    ${TrackText({
                      title: item.title,
                      artist: item.artist,
                      album: item.album
                    })}
                  </div>
                  ${item.duration || showFileExtension
                    ? html`
                        <div class="myth-playlist__item-group is-last-right">
                          ${ItemDuration({ duration: item.duration })}
                          ${showFileExtension
                            ? html`
                                <div class="myth-playlist__item-block">
                                  ${FileExtension({ text: item.format })}
                                </div>
                              `
                            : nothing}
                        </div>
                      `
                    : nothing}
                </div>
              </li>
            `;
          })}
        </ul>
      </div>
    `;
  }
);
