import {
  isEventClick,
  isKeyArrowLeft,
  isKeyArrowRight
} from 'a11y-key-conjurer';

const SKIP_TIME = 10;

function handleClick(ev, getMediaElement) {
  const audioElement = getMediaElement();
  const target = ev.currentTarget;
  const rect = target.getBoundingClientRect();
  const x = ev.clientX - rect.left;
  const percent = (100 * x) / target.offsetWidth;
  audioElement.currentTime = (audioElement.duration / 100) * percent;
}

function handleArrows({ ev, multiplier }, getMediaElement) {
  ev.preventDefault();
  const audioElement = getMediaElement();
  const newTime = audioElement.currentTime + SKIP_TIME * multiplier;
  const duration = audioElement.duration;
  audioElement.currentTime =
    newTime > 0 ? (newTime < duration ? newTime : duration) : 0;
}

function handleArrowLeft(ev, getMediaElement) {
  handleArrows({ ev, multiplier: -1 }, getMediaElement);
}

function handleArrowRight(ev, getMediaElement) {
  handleArrows({ ev, multiplier: 1 }, getMediaElement);
}

export function handleTimeline(ev, getMediaElement) {
  if (isEventClick(ev)) {
    handleClick(ev, getMediaElement);
  } else if (isKeyArrowLeft(ev)) {
    handleArrowLeft(ev, getMediaElement);
  } else if (isKeyArrowRight(ev)) {
    handleArrowRight(ev, getMediaElement);
  }
}
